==> FSang18%27s%20Heroes%20v11.8.0.jar: assets/fsang_hero/kubejs_scripts/properties.js <==
// Firstly, register the property in the entity
PalladiumEvents.registerPropertiesClientSided((event) => {
    // Only register for players
    if (event.getEntityType() === "minecraft:player") {
        // Arguments: Key of the property, type of the property, default/starting value
        event.registerProperty('asgardian_target', 'string', 'minecraft:air');
        event.registerProperty('asgardian_dim', 'string', 'minecraft:air');
        event.registerProperty('asgardian_x', 'integer', 0);
        event.registerProperty('asgardian_y', 'integer', 0);
        event.registerProperty('asgardian_z', 'integer', 0);
        event.registerProperty('fsang_r', 'integer', 0);
        event.registerProperty('fsang_g', 'integer', 0);
        event.registerProperty('fsang_b', 'integer', 0);
        event.registerProperty('fsang_cape_r', 'integer', 0);
        event.registerProperty('fsang_cape_g', 'integer', 0);
        event.registerProperty('fsang_cape_b', 'integer', 0);
        event.registerProperty('fsang_inner_cape_r', 'integer', 0);
        event.registerProperty('fsang_inner_cape_g', 'integer', 0);
        event.registerProperty('fsang_inner_cape_b', 'integer', 0);
        event.registerProperty('cape_type', 'string', 'fsang:cape_white');
        event.registerProperty('fsang_speed_trail1', 'integer', 0);
        event.registerProperty('fsang_speed_trail2', 'integer', 0);
        event.registerProperty('fsang_electrokinesis', 'integer', 0);
        event.registerProperty('fsang_electrokinesis2', 'integer', 0);
        event.registerProperty('fsang_electrokinesis_r', 'integer', 0);
        event.registerProperty('fsang_electrokinesis_g', 'integer', 0);
        event.registerProperty('fsang_electrokinesis_b', 'integer', 0);
        event.registerProperty('cursed_energy', 'integer', 0);
        event.registerProperty('name_changer', 'string', 'minecraft:air');
        event.registerProperty('skin_change', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.1', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.2', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.3', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.4', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.5', 'string', 'minecraft:air');
        event.registerProperty('standing_on_block', 'string', 'minecraft:stone');
        event.registerProperty('fsang_speedster_speed', 'integer', 0);
        event.registerProperty('fsang_speedster_speedforce', 'integer', 0);
        event.registerProperty('fsang_living_speed', 'integer', 5);
    }
    if (event.getEntityType() === "palladium:custom_projectile") {
        event.registerProperty('fsang_speed_trail1', 'integer', 0);
        event.registerProperty('fsang_speed_trail2', 'integer', 0);
    }
    if (event.getEntityType() !== "minecraft:player") {
        event.registerProperty('fsang_living_speed', 'integer', 3);
    }
});

==> FSang18%27s%20Heroes%20v11.8.4.jar: assets/fsang_hero/kubejs_scripts/properties.js <==
// Firstly, register the property in the entity
PalladiumEvents.registerPropertiesClientSided((event) => {
    // Only register for players
    if (event.getEntityType() === "minecraft:player") {
        // Arguments: Key of the property, type of the property, default/starting value
        event.registerProperty('asgardian_target', 'string', 'minecraft:air');
        event.registerProperty('asgardian_dim', 'string', 'minecraft:air');
        event.registerProperty('asgardian_x', 'integer', 0);
        event.registerProperty('asgardian_y', 'integer', 0);
        event.registerProperty('asgardian_z', 'integer', 0);
        event.registerProperty('fsang_r', 'integer', 0);
        event.registerProperty('fsang_g', 'integer', 0);
        event.registerProperty('fsang_b', 'integer', 0);
        event.registerProperty('fsang_cape_r', 'integer', 0);
        event.registerProperty('fsang_cape_g', 'integer', 0);
        event.registerProperty('fsang_cape_b', 'integer', 0);
        event.registerProperty('fsang_inner_cape_r', 'integer', 0);
        event.registerProperty('fsang_inner_cape_g', 'integer', 0);
        event.registerProperty('fsang_inner_cape_b', 'integer', 0);
        event.registerProperty('cape_type', 'string', 'fsang:cape_white');
        event.registerProperty('fsang_speed_trail1', 'integer', 0);
        event.registerProperty('fsang_speed_trail2', 'integer', 0);
        event.registerProperty('fsang_electrokinesis', 'integer', 0);
        event.registerProperty('fsang_electrokinesis2', 'integer', 0);
        event.registerProperty('fsang_electrokinesis_r', 'integer', 0);
        event.registerProperty('fsang_electrokinesis_g', 'integer', 0);
        event.registerProperty('fsang_electrokinesis_b', 'integer', 0);
        event.registerProperty('cursed_energy', 'integer', 0);
        event.registerProperty('name_changer', 'string', 'minecraft:air');
        event.registerProperty('skin_change', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.1', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.2', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.3', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.4', 'string', 'minecraft:air');
        event.registerProperty('Martian.Skin.5', 'string', 'minecraft:air');
        event.registerProperty('standing_on_block', 'string', 'minecraft:stone');
        event.registerProperty('fsang_speedster_speed', 'integer', 0);
        event.registerProperty('fsang_speedster_speedforce', 'integer', 0);
        event.registerProperty('fsang_living_speed', 'integer', 6);
        event.registerProperty('fsang_jacket_color', 'integer', 0);
        event.registerProperty('fsang_jacket_r', 'integer', 0);
        event.registerProperty('fsang_jacket_g', 'integer', 0);
        event.registerProperty('fsang_jacket_b', 'integer', 0);
        event.registerProperty('fsang_jacket_color2', 'integer', 0);
        event.registerProperty('fsang_jacket_r2', 'integer', 0);
        event.registerProperty('fsang_jacket_g2', 'integer', 0);
        event.registerProperty('fsang_jacket_b2', 'integer', 0);
        event.registerProperty('fsang_hood_color', 'integer', 0);
        event.registerProperty('fsang_hood_r', 'integer', 0);
        event.registerProperty('fsang_hood_g', 'integer', 0);
        event.registerProperty('fsang_hood_b', 'integer', 0);
    }
    if (event.getEntityType() === "palladium:custom_projectile") {
        event.registerProperty('fsang_speed_trail1', 'integer', 0);
        event.registerProperty('fsang_speed_trail2', 'integer', 0);
    }
    if (event.getEntityType() !== "minecraft:player") {
        event.registerProperty('fsang_living_speed', 'integer', 3);
    }
});
